aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--soria-theme.el30
1 files changed, 29 insertions, 1 deletions
diff --git a/soria-theme.el b/soria-theme.el
index 5f40d7a..6c7be93 100644
--- a/soria-theme.el
+++ b/soria-theme.el
@@ -413,7 +413,35 @@ The theme has to be reloaded after changing anything in this group."
:foreground ,soria-white
:underline nil)))))
- ; ansi color names
+ ;; company-mode
+
+ `(company-tooltip
+ ((,class (:background ,soria-darkgray))))
+
+ `(company-tooltip-selection
+ ((,class (:inherit helm-selection))))
+
+ `(company-tooltip-common
+ ((,class (:foreground ,soria-green))))
+
+ `(company-scrollbar-fg
+ ((,class (:background ,soria-white))))
+
+ `(company-scrollbar-bg
+ ((,class (:background ,soria-statusgray))))
+
+ `(company-preview-search
+ ((,class (:background ,soria-white))))
+
+ ;; company-box
+
+ `(company-box-candidate
+ ((,class (:foreground ,soria-white))))
+
+ `(company-box-scrollbar
+ ((,class (:inherit company-scrollbar-fg))))
+
+ ;; ansi color names
(custom-theme-set-variables
'soria
`(ansi-color-names-vector